@@ -3,8 +3,7 @@ from datetime import date
 from .https import idk
 requests = idk()
 def get(*args, **kwargs):
-    hmm = idk()
-    return hmm.get(headers=hmm.headers, *args, **kwargs)
+    return requests.get(headers=requests.headers, *args, **kwargs)
 #cars of nitrotype
 cars = {
     1 : 'Lamborgotti Mephisto SS',
